PyeLink Documentation
=====================

|PyPI| |Downloads| |License| |Documentation| |DOI|

.. |PyPI| image:: https://img.shields.io/pypi/v/pyelink
   :target: https://pypi.org/project/pyelink/
   :alt: PyPI version

.. |Downloads| image:: https://static.pepy.tech/badge/pyelink
   :target: https://pepy.tech/project/pyelink
   :alt: Downloads

.. |License| image:: https://img.shields.io/pypi/l/pyelink
   :target: https://github.com/mh-salari/pyelink/blob/main/LICENSE
   :alt: License

.. |Documentation| image:: https://readthedocs.org/projects/pyelink/badge/?version=latest
   :target: https://pyelink.readthedocs.io/
   :alt: Documentation

.. |DOI| image:: https://img.shields.io/badge/DOI-TODO-blue
   :target: https://doi.org/TODO
   :alt: DOI

**PyeLink** is a modern Python wrapper for SR Research EyeLink eye trackers with
multi-backend display support (pygame, PsychoPy, pyglet). It provides programmatic
control over the full EyeLink workflow---connection, calibration with configurable
parameters, recording with real-time data access, and direct access to any EyeLink
command for advanced configurations.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   getting_started

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api/index

.. toctree::
   :maxdepth: 1
   :caption: Reference

   direct_control
   default_settings
   eyelink_commands_reference

----

| Author: `Mohammadhossein Salari <https://mh-salari.ir>`_
